@@ -363,11 +363,11 @@ class TD:
             duration = "1 D"
         if query_time is None:
             query_time = datetime.today()
+            query_time = query_time.strftime('%Y-%m-%d') + 'T23:59:59'
+        else:
+            assert type(query_time) == datetime
         start_time = self.truedata_duration_map(duration, query_time)
 
-        query_time = query_time.strftime('%Y-%m-%d') + 'T23:59:59'
-        start_time = start_time.strftime('%Y-%m-%d') + 'T00:00:00'
-
         if bar_size == 'tick':
             hist_data = self.historical_websocket.get_hist_tick_data(contract, query_time, start_time)
         else:
@@ -387,11 +387,14 @@ class TD:
         global DEFAULT_HISTORIC_DATA_ID
         if query_time is None:
             query_time = datetime.today()
+            query_time = query_time.strftime('%Y-%m-%d') + 'T23:59:59'
+        else:
+            assert type(query_time) == datetime
         if start_time is None:
             start_time = datetime.today()
-
-        query_time = query_time.strftime('%Y-%m-%d') + 'T23:59:59'
-        start_time = start_time.strftime('%Y-%m-%d') + 'T00:00:00'
+            start_time = start_time.strftime('%Y-%m-%d') + 'T00:00:00'
+        else:
+            assert type(start_time) == datetime
 
         if bar_size == 'tick':
             hist_data = self.historical_websocket.get_hist_tick_data(contract, query_time, start_time)
